==> jc-1.4.0.tar.gz: gnu/regexp/CharIndexedString.h <==
// class gnu.regexp.CharIndexedString

// class file dependencies
// @dep_class 113c64136c06f252 gnu_regexp_CharIndexedString
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedString_H_
#define _JC_gnu_regexp_CharIndexedString_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedString$sub_refs	_jc_gnu_regexp_CharIndexedString$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedString$sub_nonrefs	_jc_gnu_regexp_CharIndexedString$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedString$refs	_jc_gnu_regexp_CharIndexedString$refs;
typedef struct _jc_gnu_regexp_CharIndexedString$nonrefs	_jc_gnu_regexp_CharIndexedString$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedString$object	_jc_gnu_regexp_CharIndexedString$object;

typedef const struct _jc_gnu_regexp_CharIndexedString$vmethods	_jc_gnu_regexp_CharIndexedString$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedString$vtable	_jc_gnu_regexp_CharIndexedString$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedString$vtype	_jc_gnu_regexp_CharIndexedString$vtype;

// Constructors
extern void _jc_gnu_regexp_CharIndexedString$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedString$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint);
extern jboolean _jc_gnu_regexp_CharIndexedString$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *);
extern jboolean _jc_gnu_regexp_CharIndexedString$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedString$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedString$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedString$method_info$move$bcf9c6b955daae71;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedString$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint);
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *);
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint);
};

// Vtable
struct _jc_gnu_regexp_CharIndexedString$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedString$vmethods	gnu_regexp_CharIndexedString;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedString$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedString$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedString$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedString$refs {
    _jc_gnu_regexp_CharIndexedString$sub_refs	gnu_regexp_CharIndexedString;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedString$sub_nonrefs {
	jint	anchor;
	jint	len;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedString$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedString$sub_nonrefs	gnu_regexp_CharIndexedString;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedString$object {
	_jc_gnu_regexp_CharIndexedString$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedString$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedString$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedString$vtype _jc_gnu_regexp_CharIndexedString$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedString, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedString$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedString_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/CharIndexedString.h <==
// class gnu.regexp.CharIndexedString

// class file dependencies
// @dep_class 113c64136c06f252 gnu_regexp_CharIndexedString
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedString_H_
#define _JC_gnu_regexp_CharIndexedString_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedString$sub_refs	_jc_gnu_regexp_CharIndexedString$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedString$sub_nonrefs	_jc_gnu_regexp_CharIndexedString$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedString$refs	_jc_gnu_regexp_CharIndexedString$refs;
typedef struct _jc_gnu_regexp_CharIndexedString$nonrefs	_jc_gnu_regexp_CharIndexedString$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedString$object	_jc_gnu_regexp_CharIndexedString$object;

typedef const struct _jc_gnu_regexp_CharIndexedString$vmethods	_jc_gnu_regexp_CharIndexedString$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedString$vtable	_jc_gnu_regexp_CharIndexedString$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedString$vtype	_jc_gnu_regexp_CharIndexedString$vtype;

// Constructors
extern void _jc_gnu_regexp_CharIndexedString$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedString$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedString$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedString$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedString$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedString$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedString$method_info$move$bcf9c6b955daae71;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedString$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *) _JC_JCNI_ATTR;
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedString$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_CharIndexedString$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedString$vmethods	gnu_regexp_CharIndexedString;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedString$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedString$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedString$sub_refs {
	struct _jc_java_lang_String$object	*s;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedString$refs {
    _jc_gnu_regexp_CharIndexedString$sub_refs	gnu_regexp_CharIndexedString;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedString$sub_nonrefs {
	jint	anchor;
	jint	len;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedString$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedString$sub_nonrefs	gnu_regexp_CharIndexedString;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedString$object {
	_jc_gnu_regexp_CharIndexedString$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedString$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedString$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedString$vtype _jc_gnu_regexp_CharIndexedString$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedString, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedString$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedString_H_ */
